@@ -355,7 +355,7 @@ class SlackInput(InputChannel):
             )
 
             return response.text(
-                None, status=HTTPStatus.CREATED, headers={"X-Slack-No-Retry": 1}
+                None, status=HTTPStatus.CREATED, headers={"X-Slack-No-Retry": 1}  # type: ignore[dict-item]  # noqa: E501
             )
 
         if metadata is not None:
