@@ -19,3 +19,7 @@ from rasa.core.policies.two_stage_fallback import TwoStageFallbackPolicy  # noqa
 from rasa.core.policies.mapping_policy import MappingPolicy  # noqa: F401
 
 from rasa.core.policies.rule_policy import RulePolicy  # noqa: F401
+
+from rasa.core.policies.unexpected_intent_policy import (  # noqa: F401
+    UnexpecTEDIntentPolicy,
+)
