@@ -1,3 +1,4 @@
+import functools
 import logging
 from typing import Any, List, Dict, Text, Optional, Set, Tuple, TYPE_CHECKING
 
@@ -144,7 +145,7 @@ class RulePolicy(MemoizationPolicy):
         self._restrict_rules = restrict_rules
         self._check_for_contradictions = check_for_contradictions
 
-        self._rules_sources = None
+        self._rules_sources = defaultdict(list)
 
         # max history is set to `None` in order to capture any lengths of rule stories
         super().__init__(
@@ -729,7 +730,7 @@ class RulePolicy(MemoizationPolicy):
         (
             rule_trackers_as_states,
             rule_trackers_as_actions,
-        ) = self.featurizer.training_states_and_actions(
+        ) = self.featurizer.training_states_and_labels(
             rule_trackers, domain, omit_unset_slots=True
         )
 
@@ -741,7 +742,7 @@ class RulePolicy(MemoizationPolicy):
         (
             story_trackers_as_states,
             story_trackers_as_actions,
-        ) = self.featurizer.training_states_and_actions(story_trackers, domain)
+        ) = self.featurizer.training_states_and_labels(story_trackers, domain)
 
         if self._check_for_contradictions:
             (
@@ -832,6 +833,9 @@ class RulePolicy(MemoizationPolicy):
         return True
 
     @staticmethod
+    # This function is called a lot (e.g. for checking contradictions) so we cache
+    # its results.
+    @functools.lru_cache(maxsize=1000)
     def _rule_key_to_state(rule_key: Text) -> List[State]:
         return json.loads(rule_key)
 
