@@ -103,7 +103,6 @@ from rasa.utils.tensorflow.constants import (
 
 logger = logging.getLogger(__name__)
 
-
 SPARSE = "sparse"
 DENSE = "dense"
 LABEL_KEY = LABEL
@@ -328,6 +327,7 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         entity_tag_specs: Optional[List[EntityTagSpec]] = None,
         model: Optional[RasaModel] = None,
         finetune_mode: bool = False,
+        sparse_feature_sizes: Optional[Dict[Text, Dict[Text, List[int]]]] = None,
     ) -> None:
         """Declare instance variables with default values."""
         if component_config is not None and EPOCHS not in component_config:
@@ -341,7 +341,7 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         self._check_config_parameters()
 
         # transform numbers to labels
-        self.index_label_id_mapping = index_label_id_mapping
+        self.index_label_id_mapping = index_label_id_mapping or {}
 
         self._entity_tag_specs = entity_tag_specs
 
@@ -352,11 +352,12 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             self.tmp_checkpoint_dir = Path(rasa.utils.io.create_temporary_directory())
 
         self._label_data: Optional[RasaModelData] = None
-        self._data_example: Optional[Dict[Text, List[FeatureArray]]] = None
+        self._data_example: Optional[Dict[Text, Dict[Text, List[FeatureArray]]]] = None
 
         self.split_entities_config = self.init_split_entities()
 
         self.finetune_mode = finetune_mode
+        self._sparse_feature_sizes = sparse_feature_sizes
 
         if not self.model and self.finetune_mode:
             raise rasa.shared.exceptions.InvalidParameterException(
@@ -559,7 +560,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             label_features = self._extract_features(e, attribute)
             for feature_key, feature_value in label_features.items():
                 features[feature_key].append(feature_value)
-
         sequence_features = []
         sentence_features = []
         for feature_name, feature_value in features.items():
@@ -571,7 +571,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
                 sentence_features.append(
                     FeatureArray(np.array(feature_value), number_of_dimensions=3)
                 )
-
         return sequence_features, sentence_features
 
     @staticmethod
@@ -614,7 +613,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         # Sort the list of tuples based on label_idx
         labels_idx_examples = sorted(labels_idx_examples, key=lambda x: x[0])
         labels_example = [example for (_, example) in labels_idx_examples]
-
         # Collect features, precomputed if they exist, else compute on the fly
         if self._check_labels_features_exist(labels_example, attribute):
             (
@@ -628,7 +626,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         label_data = RasaModelData()
         label_data.add_features(LABEL, SEQUENCE, sequence_features)
         label_data.add_features(LABEL, SENTENCE, sentence_features)
-
         if label_data.does_feature_not_exist(
             LABEL, SENTENCE
         ) and label_data.does_feature_not_exist(LABEL, SEQUENCE):
@@ -650,7 +647,8 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         return label_data
 
     def _use_default_label_features(self, label_ids: np.ndarray) -> List[FeatureArray]:
-        all_label_features = self._label_data.get(LABEL, SENTENCE)[0]
+        feature_arrays: List[FeatureArray] = self._label_data.get(LABEL, SENTENCE)
+        all_label_features = feature_arrays[0]
         return [
             FeatureArray(
                 np.array([all_label_features[label_id] for label_id in label_ids]),
@@ -693,7 +691,10 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             # no training data are present to train
             return RasaModelData()
 
-        features_for_examples = model_data_utils.featurize_training_examples(
+        (
+            features_for_examples,
+            sparse_feature_sizes,
+        ) = model_data_utils.featurize_training_examples(
             training_data,
             attributes_to_consider,
             entity_tag_specs=self._entity_tag_specs,
@@ -709,6 +710,12 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         )
         model_data.add_data(attribute_data)
         model_data.add_lengths(TEXT, SEQUENCE_LENGTH, TEXT, SEQUENCE)
+        # Current implementation doesn't yet account for updating sparse
+        # feature sizes of label attributes. That's why we remove them.
+        sparse_feature_sizes = self._remove_label_sparse_feature_sizes(
+            sparse_feature_sizes=sparse_feature_sizes, label_attribute=label_attribute
+        )
+        model_data.add_sparse_feature_sizes(sparse_feature_sizes)
 
         self._add_label_features(
             model_data, training_data, label_attribute, label_id_dict, training
@@ -721,6 +728,16 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
 
         return model_data
 
+    @staticmethod
+    def _remove_label_sparse_feature_sizes(
+        sparse_feature_sizes: Dict[Text, Dict[Text, List[int]]],
+        label_attribute: Optional[Text] = None,
+    ) -> Dict[Text, Dict[Text, List[int]]]:
+
+        if label_attribute in sparse_feature_sizes:
+            del sparse_feature_sizes[label_attribute]
+        return sparse_feature_sizes
+
     def _add_label_features(
         self,
         model_data: RasaModelData,
@@ -734,7 +751,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             for example in training_data:
                 if example.get(label_attribute):
                     label_ids.append(label_id_dict[example.get(label_attribute)])
-
             # explicitly add last dimension to label_ids
             # to track correctly dynamic sequences
             model_data.add_features(
@@ -790,7 +806,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         label_attribute = (
             INTENT if self.component_config[INTENT_CLASSIFICATION] else None
         )
-
         model_data = self._create_model_data(
             training_data.nlu_examples,
             label_id_index_mapping,
@@ -819,7 +834,6 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
                 f"Skipping training of the classifier."
             )
             return
-
         if self.component_config.get(INTENT_CLASSIFICATION):
             if not self._check_enough_labels(model_data):
                 logger.error(
@@ -840,6 +854,13 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             self.model.compile(
                 optimizer=tf.keras.optimizers.Adam(self.component_config[LEARNING_RATE])
             )
+        else:
+            self.model.adjust_for_incremental_training(
+                data_example=self._data_example,
+                new_sparse_feature_sizes=model_data.get_sparse_feature_sizes(),
+                old_sparse_feature_sizes=self._sparse_feature_sizes,
+            )
+        self._sparse_feature_sizes = model_data.get_sparse_feature_sizes()
 
         data_generator, validation_data_generator = train_utils.create_data_generators(
             model_data,
@@ -1002,6 +1023,10 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         io_utils.pickle_dump(
             model_dir / f"{file_name}.data_example.pkl", self._data_example
         )
+        io_utils.pickle_dump(
+            model_dir / f"{file_name}.sparse_feature_sizes.pkl",
+            self._sparse_feature_sizes,
+        )
         io_utils.pickle_dump(
             model_dir / f"{file_name}.label_data.pkl", dict(self._label_data.data)
         )
@@ -1046,6 +1071,7 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             label_data,
             meta,
             data_example,
+            sparse_feature_sizes,
         ) = cls._load_from_files(meta, model_dir)
 
         meta = train_utils.override_defaults(cls.defaults, meta)
@@ -1068,6 +1094,7 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             entity_tag_specs=entity_tag_specs,
             model=model,
             finetune_mode=should_finetune,
+            sparse_feature_sizes=sparse_feature_sizes,
         )
 
     @classmethod
@@ -1079,6 +1106,7 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         RasaModelData,
         Dict[Text, Any],
         Dict[Text, Dict[Text, List[FeatureArray]]],
+        Dict[Text, Dict[Text, List[int]]],
     ]:
         file_name = meta.get("file")
 
@@ -1087,6 +1115,9 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
         data_example = io_utils.pickle_load(model_dir / f"{file_name}.data_example.pkl")
         label_data = io_utils.pickle_load(model_dir / f"{file_name}.label_data.pkl")
         label_data = RasaModelData(data=label_data)
+        sparse_feature_sizes = io_utils.pickle_load(
+            model_dir / f"{file_name}.sparse_feature_sizes.pkl"
+        )
         index_label_id_mapping = io_utils.json_unpickle(
             model_dir / f"{file_name}.index_label_id_mapping.json"
         )
@@ -1118,6 +1149,7 @@ class DIETClassifier(IntentClassifier, EntityExtractor):
             label_data,
             meta,
             data_example,
+            sparse_feature_sizes,
         )
 
     @classmethod
@@ -1760,7 +1792,7 @@ class DIET(TransformerRasaModel):
 
         _, scores = self._tf_layers[
             f"loss.{LABEL}"
-        ].similarity_confidence_from_embeddings(
+        ].get_similarities_and_confidences_from_embeddings(
             sentence_vector_embed[:, tf.newaxis, :],
             self.all_labels_embed[tf.newaxis, :, :],
         )
