@@ -1,7 +1,7 @@
-import argparse
 import os
 from typing import Text, Union
 
+from rasa.shared.nlu.training_data.formats.rasa_yaml import RasaYAMLWriter
 from rasa.shared.utils.cli import print_error
 import rasa.shared.nlu.training_data.loading
 from rasa.nlu.utils import write_to_file
@@ -31,21 +31,12 @@ def convert_training_data(
         )
         return
 
+    td = rasa.shared.nlu.training_data.loading.load_data(data_file, language)
     if output_format == "json":
-        td = rasa.shared.nlu.training_data.loading.load_data(data_file, language)
         output = td.nlu_as_json(indent=2)
     elif output_format == "md":
-        td = rasa.shared.nlu.training_data.loading.load_data(data_file, language)
         output = td.nlu_as_markdown()
     else:
-        print_error(
-            "Did not recognize output format. Supported output formats: 'json' and "
-            "'md'. Specify the desired output format with '--format'."
-        )
-        return
+        output = RasaYAMLWriter().dumps(td)
 
     write_to_file(out_file, output)
-
-
-def main(args: argparse.Namespace) -> None:
-    convert_training_data(args.data, args.out, args.format, args.language)
