@@ -12,7 +12,9 @@ class Featurizer(Component):
             component_config = {}
 
         # makes sure the alias name is set
-        component_config.setdefault(FEATURIZER_CLASS_ALIAS, self.name)
+        # Necessary for `unique_name` to be defined
+        self.component_config = component_config
+        component_config.setdefault(FEATURIZER_CLASS_ALIAS, self.unique_name)
 
         super().__init__(component_config)
 
