@@ -1,9 +1,9 @@
-from typing import Any, Dict, List, Text, Pattern
+from typing import Any, Dict, List, Text
 
 import regex
-import re
 
 import rasa.shared.utils.io
+import rasa.utils.io
 from rasa.shared.constants import DOCS_URL_COMPONENTS
 from rasa.nlu.tokenizers.tokenizer import Token, Tokenizer
 from rasa.shared.nlu.training_data.message import Message
@@ -28,7 +28,7 @@ class WhitespaceTokenizer(Tokenizer):
 
         super().__init__(component_config)
 
-        self.emoji_pattern = self.get_emoji_regex()
+        self.emoji_pattern = rasa.utils.io.get_emoji_regex()
 
         if "case_sensitive" in self.component_config:
             rasa.shared.utils.io.raise_warning(
@@ -37,23 +37,6 @@ class WhitespaceTokenizer(Tokenizer):
                 docs=DOCS_URL_COMPONENTS,
             )
 
-    @staticmethod
-    def get_emoji_regex() -> Pattern:
-        """Gets regex to detect emojis in the training data."""
-        return re.compile(
-            "["
-            "\U0001F600-\U0001F64F"  # emoticons
-            "\U0001F300-\U0001F5FF"  # symbols & pictographs
-            "\U0001F680-\U0001F6FF"  # transport & map symbols
-            "\U0001F1E0-\U0001F1FF"  # flags (iOS)
-            "\U00002702-\U000027B0"
-            "\U000024C2-\U0001F251"
-            "\u200d"  # zero width joiner
-            "\u200c"  # zero width non-joiner
-            "]+",
-            flags=re.UNICODE,
-        )
-
     def remove_emoji(self, text: Text) -> Text:
         """Remove emoji if the full text, aka token, matches the emoji regex."""
         match = self.emoji_pattern.fullmatch(text)
