@@ -1,5 +1,5 @@
 from rasa.nlu.training_data.converters.nlu_markdown_to_yaml_converter import (  # noqa: F401, E501
-    NLUMarkdownToYamlConverter,
+    NLUToYamlConverter,
 )
 from rasa.nlu.training_data.converters.nlg_markdown_to_yaml_converter import (  # noqa: F401, E501
     NLGMarkdownToYamlConverter,
