@@ -145,10 +145,10 @@ def ensure_loaded_agent(
         @wraps(f)
         def decorated(*args: Any, **kwargs: Any) -> Any:
             # noinspection PyUnresolvedReferences
-            if not app.agent or not (
-                app.agent.is_core_ready()
+            if not app.ctx.agent or not (
+                app.ctx.agent.is_core_ready()
                 if require_core_is_ready
-                else app.agent.is_ready()
+                else app.ctx.agent.is_ready()
             ):
                 raise ErrorResponse(
                     HTTPStatus.CONFLICT,
@@ -172,7 +172,7 @@ def ensure_conversation_exists() -> "SanicView":
         @wraps(f)
         def decorated(request: Request, *args: Any, **kwargs: Any) -> HTTPResponse:
             conversation_id = kwargs["conversation_id"]
-            if request.app.agent.tracker_store.exists(conversation_id):
+            if request.app.ctx.agent.tracker_store.exists(conversation_id):
                 return f(request, *args, **kwargs)
             else:
                 raise ErrorResponse(
@@ -208,7 +208,7 @@ def requires_auth(
         ) -> Optional[bool]:
             # This is a coroutine since `sanic-jwt==1.6`
             jwt_data = await rasa.utils.common.call_potential_coroutine(
-                request.app.auth.extract_payload(request)
+                request.app.ctx.auth.extract_payload(request)
             )
 
             user = jwt_data.get("user", {})
@@ -241,7 +241,7 @@ def requires_auth(
                 "USE_JWT"
             ) and await rasa.utils.common.call_potential_coroutine(
                 # This is a coroutine since `sanic-jwt==1.6`
-                request.app.auth.is_authenticated(request)
+                request.app.ctx.auth.is_authenticated(request)
             ):
                 if await sufficient_scope(request, *args, **kwargs):
                     result = f(request, *args, **kwargs)
@@ -588,7 +588,7 @@ def async_if_callback_url(f: Callable[..., Coroutine]) -> Callable:
                         f"An unexpected error occurred. Error: {e}",
                     )
                 # If an error happens, we send the error payload to the `callback_url`
-                payload = dict(json=e.error_info)
+                payload = dict(json=e.error_info)  # type: ignore[dict-item]
                 logger.error(
                     "Error happened when processing request asynchronously. "
                     "Sending error to callback URL."
@@ -671,7 +671,7 @@ def create_app(
     endpoints: Optional[AvailableEndpoints] = None,
 ) -> Sanic:
     """Class representing a Rasa HTTP server."""
-    app = Sanic(__name__, register=False)
+    app = Sanic("rasa_server", register=False)
     app.config.RESPONSE_TIMEOUT = response_timeout
     configure_cors(app, cors_origins)
 
@@ -689,10 +689,10 @@ def create_app(
             user_id="username",
         )
 
-    app.agent = agent
+    app.ctx.agent = agent
     # Initialize shared object of type unsigned int for tracking
     # the number of active training processes
-    app.active_training_processes = multiprocessing.Value("I", 0)
+    app.ctx.active_training_processes = multiprocessing.Value("I", 0)
 
     @app.exception(ErrorResponse)
     async def handle_error_response(
@@ -721,10 +721,12 @@ def create_app(
 
         return response.json(
             {
-                "model_file": app.agent.path_to_model_archive
-                or app.agent.model_directory,
-                "fingerprint": model.fingerprint_from_path(app.agent.model_directory),
-                "num_active_training_jobs": app.active_training_processes.value,
+                "model_file": app.ctx.agent.path_to_model_archive
+                or app.ctx.agent.model_directory,
+                "fingerprint": model.fingerprint_from_path(
+                    app.ctx.agent.model_directory
+                ),
+                "num_active_training_jobs": app.ctx.active_training_processes.value,
             }
         )
 
@@ -736,7 +738,7 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
         until_time = rasa.utils.endpoints.float_arg(request, "until")
 
-        tracker = await app.agent.create_processor().fetch_tracker_with_initial_session(
+        tracker = await app.ctx.agent.create_processor().fetch_tracker_with_initial_session(  # noqa: E501
             conversation_id
         )
 
@@ -764,12 +766,12 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
-                processor = app.agent.create_processor()
+            async with app.ctx.agent.lock_store.lock(conversation_id):
+                processor = app.ctx.agent.create_processor()
                 events = _get_events_from_request_body(request)
 
                 tracker = await update_conversation_with_events(
-                    conversation_id, processor, app.agent.domain, events
+                    conversation_id, processor, app.ctx.agent.domain, events
                 )
 
                 output_channel = _get_output_channel(request, tracker)
@@ -781,7 +783,7 @@ def create_app(
                         events, tracker, output_channel
                     )
 
-                app.agent.tracker_store.save(tracker)
+                app.ctx.agent.tracker_store.save(tracker)
 
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
@@ -825,13 +827,13 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
+            async with app.ctx.agent.lock_store.lock(conversation_id):
                 tracker = DialogueStateTracker.from_dict(
-                    conversation_id, request.json, app.agent.domain.slots
+                    conversation_id, request.json, app.ctx.agent.domain.slots
                 )
 
                 # will override an existing tracker with the same id!
-                app.agent.tracker_store.save(tracker)
+                app.ctx.agent.tracker_store.save(tracker)
 
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
@@ -855,7 +857,7 @@ def create_app(
 
         try:
             stories = get_test_stories(
-                app.agent.create_processor(),
+                app.ctx.agent.create_processor(),
                 conversation_id,
                 until_time,
                 fetch_all_sessions=fetch_all_sessions,
@@ -891,15 +893,15 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
+            async with app.ctx.agent.lock_store.lock(conversation_id):
                 tracker = await (
-                    app.agent.create_processor().fetch_tracker_and_update_session(
+                    app.ctx.agent.create_processor().fetch_tracker_and_update_session(
                         conversation_id
                     )
                 )
 
                 output_channel = _get_output_channel(request, tracker)
-                await app.agent.execute_action(
+                await app.ctx.agent.execute_action(
                     conversation_id,
                     action_to_execute,
                     output_channel,
@@ -944,20 +946,20 @@ def create_app(
         verbosity = event_verbosity_parameter(request, EventVerbosity.AFTER_RESTART)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
+            async with app.ctx.agent.lock_store.lock(conversation_id):
                 tracker = await (
-                    app.agent.create_processor().fetch_tracker_and_update_session(
+                    app.ctx.agent.create_processor().fetch_tracker_and_update_session(
                         conversation_id
                     )
                 )
                 output_channel = _get_output_channel(request, tracker)
-                if intent_to_trigger not in app.agent.domain.intents:
+                if intent_to_trigger not in app.ctx.agent.domain.intents:
                     raise ErrorResponse(
                         HTTPStatus.NOT_FOUND,
                         "NotFound",
                         f"The intent {trigger_intent} does not exist in the domain.",
                     )
-                await app.agent.trigger_intent(
+                await app.ctx.agent.trigger_intent(
                     intent_name=intent_to_trigger,
                     entities=entities,
                     output_channel=output_channel,
@@ -989,7 +991,7 @@ def create_app(
     async def predict(request: Request, conversation_id: Text) -> HTTPResponse:
         try:
             # Fetches the appropriate bot response in a json format
-            responses = await app.agent.predict_next(conversation_id)
+            responses = await app.ctx.agent.predict_next(conversation_id)
             responses["scores"] = sorted(
                 responses["scores"], key=lambda k: (-k["score"], k["action"])
             )
@@ -1033,8 +1035,8 @@ def create_app(
         user_message = UserMessage(message, None, conversation_id, parse_data)
 
         try:
-            async with app.agent.lock_store.lock(conversation_id):
-                tracker = await app.agent.log_message(user_message)
+            async with app.ctx.agent.lock_store.lock(conversation_id):
+                tracker = await app.ctx.agent.log_message(user_message)
 
             return response.json(tracker.current_state(verbosity))
         except Exception as e:
@@ -1063,8 +1065,8 @@ def create_app(
             training_payload = _training_payload_from_json(request, temporary_directory)
 
         try:
-            with app.active_training_processes.get_lock():
-                app.active_training_processes.value += 1
+            with app.ctx.active_training_processes.get_lock():
+                app.ctx.active_training_processes.value += 1
 
             from rasa.model_training import train_async
 
@@ -1101,8 +1103,8 @@ def create_app(
                 f"An unexpected error occurred during training. Error: {e}",
             )
         finally:
-            with app.active_training_processes.get_lock():
-                app.active_training_processes.value -= 1
+            with app.ctx.active_training_processes.get_lock():
+                app.ctx.active_training_processes.value -= 1
 
     @app.post("/model/test/stories")
     @requires_auth(app, auth_token)
@@ -1124,7 +1126,7 @@ def create_app(
 
         try:
             evaluation = await test(
-                test_data, app.agent, e2e=use_e2e, disable_plotting=True
+                test_data, app.ctx.agent, e2e=use_e2e, disable_plotting=True
             )
             return response.json(evaluation)
         except Exception as e:
@@ -1193,10 +1195,10 @@ def create_app(
     ) -> Dict:
         logger.info("Starting model evaluation using test set.")
 
-        eval_agent = app.agent
+        eval_agent = app.ctx.agent
 
         if model_path:
-            model_server = app.agent.model_server
+            model_server = app.ctx.agent.model_server
             if model_server is not None:
                 model_server = model_server.copy()
                 model_server.url = model_path
@@ -1204,7 +1206,7 @@ def create_app(
                 # a job to pull the model from the server
                 model_server.kwargs["wait_time_between_pulls"] = 0
             eval_agent = await _load_agent(
-                model_path, model_server, app.agent.remote_storage
+                model_path, model_server, app.ctx.agent.remote_storage
             )
 
         data_path = os.path.abspath(test_data_file)
@@ -1281,7 +1283,7 @@ def create_app(
         request_params = request.json
         try:
             tracker = DialogueStateTracker.from_dict(
-                DEFAULT_SENDER_ID, request_params, app.agent.domain.slots
+                DEFAULT_SENDER_ID, request_params, app.ctx.agent.domain.slots
             )
         except Exception as e:
             logger.debug(traceback.format_exc())
@@ -1293,7 +1295,7 @@ def create_app(
             )
 
         try:
-            result = app.agent.create_processor().predict_next_with_tracker(
+            result = app.ctx.agent.create_processor().predict_next_with_tracker(
                 tracker, verbosity
             )
 
@@ -1321,7 +1323,7 @@ def create_app(
         try:
             data = emulator.normalise_request_json(request.json)
             try:
-                parsed_data = await app.agent.parse_message_using_nlu_interpreter(
+                parsed_data = await app.ctx.agent.parse_message_using_nlu_interpreter(
                     data.get("text")
                 )
             except Exception as e:
@@ -1364,8 +1366,12 @@ def create_app(
                     {"parameter": "model_server", "in": "body"},
                 )
 
-        app.agent = await _load_agent(
-            model_path, model_server, remote_storage, endpoints, app.agent.lock_store
+        app.ctx.agent = await _load_agent(
+            model_path,
+            model_server,
+            remote_storage,
+            endpoints,
+            app.ctx.agent.lock_store,
         )
 
         logger.debug(f"Successfully loaded model '{model_path}'.")
@@ -1374,9 +1380,9 @@ def create_app(
     @app.delete("/model")
     @requires_auth(app, auth_token)
     async def unload_model(request: Request) -> HTTPResponse:
-        model_file = app.agent.model_directory
+        model_file = app.ctx.agent.model_directory
 
-        app.agent = Agent(lock_store=app.agent.lock_store)
+        app.ctx.agent = Agent(lock_store=app.ctx.agent.lock_store)
 
         logger.debug(f"Successfully unloaded model '{model_file}'.")
         return response.json(None, status=HTTPStatus.NO_CONTENT)
@@ -1388,10 +1394,10 @@ def create_app(
         """Get current domain in yaml or json format."""
         accepts = request.headers.get("Accept", default=JSON_CONTENT_TYPE)
         if accepts.endswith("json"):
-            domain = app.agent.domain.as_dict()
+            domain = app.ctx.agent.domain.as_dict()
             return response.json(domain)
         elif accepts.endswith("yml") or accepts.endswith("yaml"):
-            domain_yaml = app.agent.domain.as_yaml()
+            domain_yaml = app.ctx.agent.domain.as_yaml()
             return response.text(
                 domain_yaml, status=HTTPStatus.OK, content_type=YAML_CONTENT_TYPE
             )
@@ -1432,7 +1438,7 @@ def _get_output_channel(
         requested_output_channel = tracker.get_latest_input_channel()
 
     # Interactive training does not set `input_channels`, hence we have to be cautious
-    registered_input_channels = getattr(request.app, "input_channels", None) or []
+    registered_input_channels = getattr(request.app.ctx, "input_channels", None) or []
     matching_channels = [
         channel
         for channel in registered_input_channels
