@@ -14,7 +14,7 @@ from typing import Dict, Text, List, Any, Union, Tuple, Optional
 
 import rasa.shared.data
 from rasa.shared.core.domain import Domain
-from rasa.shared.nlu.constants import TEXT, INTENT_NAME_KEY
+from rasa.shared.nlu.constants import INTENT_NAME_KEY
 from rasa.shared.nlu.training_data.message import Message
 from rasa.shared.constants import (
     INTENT_MESSAGE_PREFIX,
@@ -60,7 +60,9 @@ class MarkdownStoryReader(StoryReader):
                 docs=DOCS_URL_MIGRATION_GUIDE_MD_DEPRECATION,
             )
 
-    def read_from_file(self, filename: Union[Text, Path]) -> List[StoryStep]:
+    def read_from_file(
+        self, filename: Union[Text, Path], skip_validation: bool = False
+    ) -> List[StoryStep]:
         """Given a md file reads the contained stories."""
         try:
             with open(
