@@ -109,7 +109,7 @@ def _auto_configure(
     if keys_to_configure:
         logger.debug(
             f"The provided configuration does not contain the key(s) "
-            f"{rasa.shared.utils.common.transform_collection_to_sentence(keys_to_configure)}. "
+            f"{rasa.shared.utils.common.transform_collection_to_sentence(keys_to_configure)}. "  # noqa: E501, W505
             f"Values will be provided from the default configuration."
         )
 
