@@ -4,7 +4,7 @@ import os
 from functools import wraps
 
 import numpy as np
-from typing import Any, Callable, List, Optional, Text, TypeVar, Union
+from typing import Any, Callable, List, Optional, Text, TypeVar, Union, Tuple
 import matplotlib
 from matplotlib.ticker import FormatStrFormatter
 
@@ -145,82 +145,143 @@ def plot_confusion_matrix(
         fig.savefig(output_file, bbox_inches="tight")
 
 
+def _extract_paired_histogram_specification(
+    histogram_data: List[List[float]],
+    num_bins: int,
+    density: bool,
+    x_pad_fraction: float,
+    y_pad_fraction: float,
+) -> Tuple[List[float], List[List[float]], List[float], Tuple[float, float]]:
+    """Extracts all information from the data needed to plot a paired histogram.
+
+    Args:
+        histogram_data: Two data vectors
+        num_bins: Number of bins to be used for the histogram
+        density: If true, generate information for a probability density histogram
+        x_pad_fraction: Percentage of extra space in the horizontal direction
+        y_pad_fraction: Percentage of extra space in the vertical direction
+
+    Returns:
+        The bins, values, ranges of either x-axis, and the range of the y-axis
+
+    Raises:
+        ValueError: If histogram_data does not contain values.
+    """
+    if not histogram_data or not np.concatenate(histogram_data).size:
+        rasa.shared.utils.io.raise_warning("No data to plot paired histogram.")
+        raise ValueError("No data to plot paired histogram.")
+    min_data_value = np.min(np.concatenate(histogram_data))
+    max_data_value = np.max(np.concatenate(histogram_data))
+    bin_width = (max_data_value - min_data_value) / num_bins
+    bins = [
+        min_data_value + i * bin_width
+        # `bins` describes the _boundaries_ of the bins, so we need
+        # 2 extra - one at the beginning and one at the end
+        for i in range(num_bins + 2)
+    ]
+    histograms = [
+        # A list of counts - how often a value in `data` falls into a particular bin
+        np.histogram(data, bins=bins, density=density)[0]
+        for data in histogram_data
+    ]
+
+    y_padding = 0.5 * bin_width + y_pad_fraction * bin_width
+
+    if density:
+        # Get the maximum count across both histograms, and scale it
+        # with `x_pad_fraction`
+        v = max([(1.0 + x_pad_fraction) * max(histogram) for histogram in histograms])
+        # When we plot the PDF, let both x-axes run to the same value
+        # so it's easier to compare visually
+        x_ranges = [v, v]
+    else:
+        # For the left and right histograms, get the largest counts and scale them
+        # by `x_pad_fraction` to get the maximum x-values displayed
+        x_ranges = [(1.0 + x_pad_fraction) * max(histogram) for histogram in histograms]
+
+    bin_of_first_non_zero_tally = min(
+        [(histogram != 0).argmax(axis=0) for histogram in histograms]
+    )
+
+    y_range = (
+        # Start plotting where the data starts (ignore empty bins at the low end)
+        bins[bin_of_first_non_zero_tally] - y_padding,
+        # The y_padding adds half a bin width, as we want the bars to be
+        # _centered_ on the bins. We take the next-to-last element of `bins`,
+        # because that is the beginning of the last bin.
+        bins[-2] + y_padding,
+    )
+
+    return bins, histograms, x_ranges, y_range
+
+
 @_needs_matplotlib_backend
-def plot_histogram(
-    hist_data: List[List[float]], title: Text, output_file: Optional[Text] = None
+def plot_paired_histogram(
+    histogram_data: List[List[float]],
+    title: Text,
+    output_file: Optional[Text] = None,
+    num_bins: int = 25,
+    colors: Tuple[Text, Text] = ("#009292", "#920000",),  # (dark cyan, dark red)
+    axes_label: Tuple[Text, Text] = ("Correct", "Wrong"),
+    frame_label: Tuple[Text, Text] = ("Number of Samples", "Confidence"),
+    density: bool = False,
+    x_pad_fraction: float = 0.05,
+    y_pad_fraction: float = 0.10,
 ) -> None:
     """Plots a side-by-side comparative histogram of the confidence distribution.
 
     Args:
-        hist_data: histogram data
-        title: title of the plot
-        output_file: output file to save the plot to
+        histogram_data: Two data vectors
+        title: Title to be displayed above the plot
+        output_file: File to save the plot to
+        num_bins: Number of bins to be used for the histogram
+        colors: Left and right bar colors as hex color strings
+        axes_label: Labels shown above the left and right histogram,
+            respectively
+        frame_label: Labels shown below and on the left of the
+            histogram, respectively
+        density: If true, generate a probability density histogram
+        x_pad_fraction: Percentage of extra space in the horizontal direction
+        y_pad_fraction: Percentage of extra space in the vertical direction
     """
+    if num_bins <= 2:
+        rasa.shared.utils.io.raise_warning(
+            f"Number {num_bins} of paired histogram bins must be at least 3."
+        )
+        return
+
+    try:
+        bins, tallies, x_ranges, y_range = _extract_paired_histogram_specification(
+            histogram_data,
+            num_bins,
+            density=density,
+            x_pad_fraction=x_pad_fraction,
+            y_pad_fraction=y_pad_fraction,
+        )
+    except ValueError as e:
+        rasa.shared.utils.io.raise_warning(
+            f"Unable to plot paired histogram '{title}': {e}"
+        )
+        return
+    yticks = [float(f"{x:.2f}") for x in bins]
+
     import matplotlib.pyplot as plt
 
     plt.gcf().clear()
 
-    # Wine-ish colour for the confidences of hits.
-    # Blue-ish colour for the confidences of misses.
-    colors = ["#009292", "#920000"]
-    n_bins = 25
-    max_value = max(
-        [max(hist_data[0], default=0), max(hist_data[1], default=0)], default=0
-    )
-    min_value = min(
-        [min(hist_data[0], default=0), min(hist_data[1], default=0)], default=0
-    )
-
-    bin_width = (max_value - min_value) / n_bins
-    bins = [min_value + (i * bin_width) for i in range(1, n_bins + 1)]
-
-    binned_data_sets = [np.histogram(d, bins=bins)[0] for d in hist_data]
-
-    max_xlims = [max(binned_data_set) for binned_data_set in binned_data_sets]
-    max_xlims = [xlim + np.ceil(0.25 * xlim) for xlim in max_xlims]  # padding
-
-    min_ylim = (
-        bins[
-            min(
-                [
-                    (binned_data_set != 0).argmax(axis=0)
-                    for binned_data_set in binned_data_sets
-                ]
-            )
-        ]
-        - bin_width
-    )
-
-    max_ylim = max(bins) + bin_width
-
-    yticks = [float("{:.2f}".format(x)) for x in bins]
-
-    centers = 0.5 * (0.05 + (bins + np.roll(bins, 0))[:-1])
-    heights = 0.75 * np.diff(bins)
-
     fig, axes = plt.subplots(ncols=2, sharey=True)
-    axes[0].barh(
-        centers,
-        binned_data_sets[0],
-        height=heights,
-        align="center",
-        color=colors[0],
-        label="hits",
-    )
-    axes[0].set(title="Correct")
-    axes[1].barh(
-        centers,
-        binned_data_sets[1],
-        height=heights,
-        align="center",
-        color=colors[1],
-        label="misses",
-    )
-
-    axes[1].set(title="Wrong")
-
-    axes[0].set(yticks=yticks, xlim=(0, max_xlims[0]), ylim=(min_ylim, max_ylim))
-    axes[1].set(yticks=yticks, xlim=(0, max_xlims[1]), ylim=(min_ylim, max_ylim))
+    for side in range(2):
+        axes[side].barh(
+            bins[:-1],
+            tallies[side],
+            height=np.diff(bins),
+            align="center",
+            color=colors[side],
+            linewidth=1,
+            edgecolor="white",
+        )
+        axes[side].set(title=axes_label[side])
+        axes[side].set(yticks=yticks, xlim=(0, x_ranges[side]), ylim=y_range)
 
     axes[0].yaxis.set_major_formatter(FormatStrFormatter("%.2f"))
     axes[0].yaxis.set_minor_formatter(FormatStrFormatter("%.2f"))
@@ -228,21 +289,21 @@ def plot_histogram(
     axes[0].invert_xaxis()
     axes[0].yaxis.tick_right()
 
-    fig.subplots_adjust(
-        wspace=0.17
-    )  # get the graphs exactly far enough apart for yaxis labels
+    # Add the title
     fig.suptitle(title, fontsize="x-large", fontweight="bold")
 
-    # Add hidden plot to correctly add x and y labels
+    # Add hidden plot to correctly add x and y labels (frame_label)
     fig.add_subplot(111, frameon=False)
-    # Hide tick and tick label of the big axis
+
+    # Hide tick and tick label of the unused axis
     plt.tick_params(labelcolor="none", top=False, bottom=False, left=False, right=False)
-    plt.ylabel("Confidence")
-    plt.xlabel("Number of Samples")
+    plt.xlabel(frame_label[0])
+    plt.ylabel(frame_label[1])
 
     if output_file:
         fig = plt.gcf()
         fig.set_size_inches(10, 10)
+        fig.tight_layout(w_pad=0)
         fig.savefig(output_file, bbox_inches="tight")
 
 
@@ -265,6 +326,8 @@ def plot_curve(
     """
     import matplotlib.pyplot as plt
 
+    plt.gcf().clear()
+
     ax = plt.gca()
 
     # load results from file
